
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.19.7',
    'branch_nick': 'patch-0-Release__Rucio_1_19_7_preparation',
    'revision_id': '22e8c69f42c87cbcb361c9c11f51eb010d2b4706',
    'revno': 7998
}
